
# Slot: preceded by


holds between two processes, where the other is completed before the one begins

URI: [biolink:preceded_by](https://w3id.org/biolink/vocab/preceded_by)


## Domain and Range

[Occurrent](Occurrent.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [temporally related to](temporally_related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | BFO:0000062 |
| **Narrow Mappings:** | | FMA:transforms_from |
|  | | RO:0002087 |
|  | | RO:0002285 |
| **Broad Mappings:** | | GENEPIO:0001739 |

